(* ------------------------------------------------------------------- *)
(* Determination of Kappa                                                   *)
(* ------------------------------------------------------------------- *)



(* ------------------------------------------------------------------- *)
(* Constants                                                                         *)
(* ------------------------------------------------------------------- *)
ms = 0.2;
mb = 4.8;
mc = 1.4;
mt = 170;
mw = 80.22;
mu = 5;
xt = (mt/mw)^2;
mchat = mc/mb;
mshat = ms/mb;
ckm = 1;
lamdaqcd = 0.195;
alphaweak = 1/130;
alphastrongmw = 4 Pi/(23/3 Log[mw^2/lamdaqcd^2]) (1 - 
	(116/3)/(23/3)^2 Log[Log[mw^2/lamdaqcd^2]]/Log[mw^2/lamdaqcd^2]);
alphastrongmu = 4 Pi/(23/3 Log[mu^2/lamdaqcd^2]) (1 - 
	(116/3)/(23/3)^2 Log[Log[mu^2/lamdaqcd^2]]/Log[mu^2/lamdaqcd^2]);
eta = alphastrongmw/alphastrongmu;
brbxlv = 0.104;
gammabsv = 3.5 10^(-3);
mv = 3.686;
gammavee = 2.14 10^(-6);

(* ------------------------------------------------------------------- *)
(* Definition of functions                                                      *)
(* ------------------------------------------------------------------- *)
phasefactor = 1 - 8 mchat^2 + 8 mchat^6 - mchat^8 - 
	24 mchat^4 Log[mchat];
kappamu = 1 - (2 alphastrongmu)/(3 Pi) ((Pi^2 - 31/4)(
	1 - mchat)^2 + 3/2);
overwholefactor = brbxlv (ckm^2)/(mb^8) 1/(phasefactor kappamu) (
	9 Pi)/(4 alphaweak^2);
uhat = Sqrt[(mv^2 - (mb + ms)^2)(mv^2 - (mb - ms)^2)];
alpha1 = -2 mv^4 + (mb^2 + ms^2) mv^2 + (mb^2 - ms^2)^2;
c1mb = 1/2 (eta^(6/23) - eta^(-12/23));
c2mb = 1/2 (eta^(6/23) + eta^(-12/23));
c3mb = -1/14 eta^(6/23) + 1/6 eta^(-12/23) + 0.0510 eta^(0.4086) - 
	0.1403 eta^(-0.4230) - 0.0113 eta^(-0.8994) + 
	0.0054 eta^(0.1456);
c4mb = -1/14 eta^(6/23) - 1/6 eta^(-12/23) + 0.0984 eta^(0.4086) + 
	0.1214  eta^(-0.4230) + 0.0156 eta^(-0.8994) + 
	0.0026 eta^(0.1456);
c5mb = -0.0397 eta^(0.4086) + 0.0117 eta^(-0.4230) - 
	0.0025  eta^(-0.8994) + 0.0304 eta^(0.1456);
c6mb = 0.0335 eta^(0.4086) + 0.0239 eta^(-0.4230) - 
	0.0462  eta^(-0.8994) - 0.0112 eta^(0.1456);
c = 3 c1mb + c2mb + 3 c3mb + c4mb + 3 c5mb + c6mb;
lhs = gammabsv;
rhs = overwholefactor c^2 mv uhat alpha1 gammavee;
kappa = N[Sqrt[lhs/rhs]]
rhsc = overwholefactor mv uhat alpha1 gammavee;
kappac = N[Sqrt[lhs/rhsc]]
